# eric7.DocumentationTools.QtHelpGenerator

Module implementing the QtHelp generator for the builtin documentation generator.

### Global Attributes

HelpCollection
HelpCollectionFile
HelpCollectionProjectFile
HelpHelpFile
HelpProject
HelpProjectFile

### Classes

QtHelpGenerator | Class implementing the QtHelp generator for the builtin documentation generator.

### Functions

None

## QtHelpGenerator

Class implementing the QtHelp generator for the builtin documentation generator.

### Derived from

None

### Class Attributes

None

### Class Methods

None

### Methods

QtHelpGenerator | Constructor
__convertEol | Private method to convert the newline characters.
__generateSections | Private method to generate the sections part.
generateFiles | Public method to generate all index files.
remember | Public method to remember a documentation file.

### Static Methods

None

#### QtHelpGenerator (Constructor)

QtHelpGenerator(htmlDir, outputDir, namespace, virtualFolder, filterName, filterAttributes, title, createCollection, )

Constructor

htmlDir (str)
  directory containing the HTML files
outputDir (str)
  output directory for the files
namespace (str)
  namespace to be used
virtualFolder (str)
  virtual folder to be used
filterName (str)
  name of the custom filter
filterAttributes (str)
  ':' separated list of filter attributes
title (str)
  title to be used for the generated help
createCollection (bool)
  flag indicating the generation of the collection files

#### QtHelpGenerator.__convertEol

__convertEol(txt, newline)

Private method to convert the newline characters.

txt (str)
  text to be converted
newline (str)
  newline character to be used

Return:
  converted text

Return Type:
  str

#### QtHelpGenerator.__generateSections

__generateSections(package, level)

Private method to generate the sections part.

package (str)
  name of the package to process
level (int)
  indentation level

Return:
  sections part

Return Type:
  str

#### QtHelpGenerator.generateFiles

generateFiles(basename="", newline=None)

Public method to generate all index files.

basename (str)
  base name of the file hierarchy to be documented. The base name is stripped off the filename if it starts with the base name.
newline (str)
  newline character to be used

#### QtHelpGenerator.remember

remember(file, moduleDocument, basename="")

Public method to remember a documentation file.

file (str)
  The filename to be remembered.
moduleDocument (ModuleDocument)
  module documentation object containing the information for the file.
basename (str)
  base name of the file hierarchy to be documented. The base name is stripped off the filename if it starts with the base name.

Up